@@ -65,10 +65,10 @@ def Deconvolution(sc_reference, real_bulk, sep='\t',
         Sigm = None
         return Sigm, Pred
 
-def ScadenDeconvolution(sc_reference, real_bulk, sep='\t', genelenfile=None):
+def ScadenDeconvolution(sc_reference, real_bulk, sep='\t'):
     simudata = generate_simulated_data(sc_data=sc_reference, samplenum=5000)
     train_x, train_y, test_x, genename, celltypes, samplename = \
-        ProcessInputData(simudata, real_bulk, sep=sep, datatype='counts', genelenfile=genelenfile)
+        ProcessInputData(simudata, real_bulk, sep=sep, datatype='counts', genelenfile=None)
     print('training data shape is ', train_x.shape, '\ntest data shape is ', test_x.shape)
     pred = test_scaden(train_x,train_y,test_x,batch_size=128)
     pred = pd.DataFrame(pred, columns=celltypes, index=samplename)
